subroutine calculate_transmission(s, el, r_evan_inner, r_evan_outer, sgn_Sl2_minus_N2, int_kappa_dr_evan)
    implicit none

    ! This subroutine calculates the boundaries of the evanescent zone
    ! at nu_max, as well as the transmission coefficient integral
    integer :: id, ierr
    type (star_info), pointer :: s

    ! Input parameters
    real(dp), intent(in) :: el ! angular degree

    ! Define variables to write out
    real(dp), intent(out) :: r_evan_inner, r_evan_outer
    real(dp), intent(out) :: sgn_Sl2_minus_N2
    real(dp), intent(out) :: int_kappa_dr_evan

    ! Helpers
    real(dp) :: omega2, csound2, Sl2, N2
    logical :: evan_found ! for loop, has evanescent region been found?
    real(dp) :: kappa2 ! -kr^2
    real(dp) :: dr
    integer :: k

    evan_found = .false.
    r_evan_inner = -1.d0
    r_evan_outer = -1.d0
    sgn_Sl2_minus_N2 = 0.d0
    int_kappa_dr_evan = 0.d0

    evan_found = .false.
    omega2 = pow2(1.d-6 * 2 * pi * s% nu_max) ! angular Hz^2
    
    do k = 1, s% nz - 1
        ! To avoid surface radiative zone, only start search sufficiently deep into the star
        if (s% r(k) <= 0.9 * s% r(1)) then
            csound2 = pow2(s% csound_face(k))
            Sl2 = el * (el + 1) * csound2 / pow2(s% r(k))
            N2 = s% brunt_N2(k)

            kappa2 = (Sl2 - omega2) * (omega2 - N2) / omega2 / csound2

            if (kappa2 > 0) then
                if (.not. evan_found) then
                    evan_found = .true.
                    r_evan_outer = s% r(k) / Rsun
                    sgn_Sl2_minus_N2 = sign(1.d0, Sl2 - N2)
                end if

                dr = s% rmid(k) - s% rmid(k+1)

                int_kappa_dr_evan = int_kappa_dr_evan + sqrt(kappa2) * dr

            else if (evan_found) then
                r_evan_inner = s% r(k-1) / Rsun
                exit
            end if
        end if
    end do

end subroutine
